summaryrefslogtreecommitdiff
path: root/indra/cmake/GStreamer010Plugin.cmake
diff options
context:
space:
mode:
Diffstat (limited to 'indra/cmake/GStreamer010Plugin.cmake')
-rwxr-xr-xindra/cmake/GStreamer010Plugin.cmake4
1 files changed, 2 insertions, 2 deletions
diff --git a/indra/cmake/GStreamer010Plugin.cmake b/indra/cmake/GStreamer010Plugin.cmake
index d2d0699bcd..d1c99d5409 100755
--- a/indra/cmake/GStreamer010Plugin.cmake
+++ b/indra/cmake/GStreamer010Plugin.cmake
@@ -8,8 +8,8 @@ if (STANDALONE)
pkg_check_modules(GSTREAMER010_PLUGINS_BASE REQUIRED gstreamer-plugins-base-0.10)
elseif (LINUX)
use_prebuilt_binary(gstreamer)
- # possible libxml should have its own .cmake file instead
- use_prebuilt_binary(libxml)
+ # possible libxml2 should have its own .cmake file instead
+ use_prebuilt_binary(libxml2)
set(GSTREAMER010_FOUND ON FORCE BOOL)
set(GSTREAMER010_PLUGINS_BASE_FOUND ON FORCE BOOL)
set(GSTREAMER010_INCLUDE_DIRS